@@ -23,6 +23,7 @@
 
 #include "adw-header-bar.h"
 
+#include "adw-adaptive-preview-private.h"
 #include "adw-back-button-private.h"
 #include "adw-bin.h"
 #include "adw-bottom-sheet-private.h"
@@ -186,6 +187,7 @@ struct _AdwHeaderBar {
   GtkWidget *title_navigation_page;
   GtkWidget *dialog;
   GtkWidget *sheet;
+  GtkWidget *adaptive_preview;
 
   GSList *split_views;
 };
@@ -332,14 +334,23 @@ update_start_title_buttons (AdwHeaderBar *self)
   gboolean show = self->show_start_title_buttons;
   GSList *l;
 
+  if (self->adaptive_preview &&
+      !adw_adaptive_preview_get_window_controls (ADW_ADAPTIVE_PREVIEW (self->adaptive_preview))) {
+    show = FALSE;
+  }
+
   for (l = self->split_views; l; l = l->next) {
     SplitViewData *data = l->data;
 
     if (ADW_IS_NAVIGATION_SPLIT_VIEW (data->split_view)) {
       AdwNavigationSplitView *split_view = ADW_NAVIGATION_SPLIT_VIEW (data->split_view);
       gboolean collapsed = adw_navigation_split_view_get_collapsed (split_view);
+      GtkPackType sidebar_pos = adw_navigation_split_view_get_sidebar_position (split_view);
 
-      show &= data->is_sidebar || collapsed;
+      if (data->is_sidebar)
+        show &= collapsed || sidebar_pos == GTK_PACK_START;
+      else
+        show &= collapsed || sidebar_pos == GTK_PACK_END;
     }
 
     if (ADW_IS_OVERLAY_SPLIT_VIEW (data->split_view)) {
@@ -371,14 +382,23 @@ update_end_title_buttons (AdwHeaderBar *self)
   gboolean show = self->show_end_title_buttons;
   GSList *l;
 
+  if (self->adaptive_preview &&
+      !adw_adaptive_preview_get_window_controls (ADW_ADAPTIVE_PREVIEW (self->adaptive_preview))) {
+    show = FALSE;
+  }
+
   for (l = self->split_views; l; l = l->next) {
     SplitViewData *data = l->data;
 
     if (ADW_IS_NAVIGATION_SPLIT_VIEW (data->split_view)) {
       AdwNavigationSplitView *split_view = ADW_NAVIGATION_SPLIT_VIEW (data->split_view);
       gboolean collapsed = adw_navigation_split_view_get_collapsed (split_view);
+      GtkPackType sidebar_pos = adw_navigation_split_view_get_sidebar_position (split_view);
 
-      show &= !data->is_sidebar || collapsed;
+      if (data->is_sidebar)
+        show &= collapsed || sidebar_pos == GTK_PACK_END;
+      else
+        show &= collapsed || sidebar_pos == GTK_PACK_START;
     }
 
     if (ADW_IS_OVERLAY_SPLIT_VIEW (data->split_view)) {
@@ -496,11 +516,30 @@ find_sheet (GtkWidget *widget)
   return NULL;
 }
 
+static GtkWidget *
+find_adaptive_preview (GtkWidget *widget, GtkWidget **screen_view)
+{
+  GtkWidget *preview, *screen;
+
+  preview = adw_widget_get_ancestor (widget, ADW_TYPE_ADAPTIVE_PREVIEW, TRUE, TRUE);
+  if (!preview)
+    return NULL;
+
+  screen = adw_adaptive_preview_get_screen (ADW_ADAPTIVE_PREVIEW (preview));
+
+  if (gtk_widget_is_ancestor (widget, screen)) {
+    *screen_view = screen;
+    return preview;
+  }
+
+  return NULL;
+}
+
 static void
 adw_header_bar_root (GtkWidget *widget)
 {
   AdwHeaderBar *self = ADW_HEADER_BAR (widget);
-  GtkWidget *parent;
+  GtkWidget *parent, *screen_view = NULL;
 
   GTK_WIDGET_CLASS (adw_header_bar_parent_class)->root (widget);
 
@@ -508,6 +547,7 @@ adw_header_bar_root (GtkWidget *widget)
     adw_widget_get_ancestor (widget, ADW_TYPE_NAVIGATION_PAGE, TRUE, TRUE);
 
   self->dialog = adw_widget_get_ancestor (widget, ADW_TYPE_DIALOG, TRUE, FALSE);
+  self->adaptive_preview = find_adaptive_preview (widget, &screen_view);
   self->sheet = find_sheet (widget);
 
   if (ADW_IS_BOTTOM_SHEET (self->sheet)) {
@@ -515,6 +555,11 @@ adw_header_bar_root (GtkWidget *widget)
                               G_CALLBACK (update_title), widget);
   }
 
+  if (self->adaptive_preview) {
+    g_signal_connect_swapped (self->adaptive_preview, "notify::window-controls",
+                              G_CALLBACK (update_title_buttons), widget);
+  }
+
   if (self->title_navigation_page) {
     g_signal_connect_swapped (self->title_navigation_page, "notify::title",
                               G_CALLBACK (update_title), widget);
@@ -535,8 +580,11 @@ adw_header_bar_root (GtkWidget *widget)
     GtkWidget *split_view = NULL;
     gboolean is_sidebar = FALSE;
 
-    if (GTK_IS_NATIVE (parent))
+    if (GTK_IS_NATIVE (parent) ||
+        parent == self->sheet ||
+        parent == screen_view) {
       break;
+    }
 
     if (ADW_IS_NAVIGATION_SPLIT_VIEW (parent)) {
       AdwNavigationPage *sidebar;
@@ -545,6 +593,8 @@ adw_header_bar_root (GtkWidget *widget)
 
       g_signal_connect_swapped (split_view, "notify::collapsed",
                                 G_CALLBACK (update_title_buttons), widget);
+      g_signal_connect_swapped (split_view, "notify::sidebar-position",
+                                G_CALLBACK (update_title_buttons), widget);
 
       sidebar = adw_navigation_split_view_get_sidebar (ADW_NAVIGATION_SPLIT_VIEW (split_view));
 
@@ -609,6 +659,11 @@ adw_header_bar_unroot (GtkWidget *widget)
                                           update_title, widget);
   }
 
+  if (self->adaptive_preview) {
+    g_signal_handlers_disconnect_by_func (self->adaptive_preview,
+                                          update_title_buttons, widget);
+  }
+
   self->title_navigation_page = NULL;
   self->dialog = NULL;
   self->sheet = FALSE;
