@@ -26,8 +26,11 @@ struct _AdwInspectorPage
   AdwSwitchRow *high_contrast_row;
   AdwSwitchRow *support_accent_colors_row;
   AdwComboRow *accent_color_row;
+  GtkListBox *windows_list;
 
   GObject *object;
+
+  gboolean realized;
 };
 
 G_DEFINE_FINAL_TYPE (AdwInspectorPage, adw_inspector_page, ADW_TYPE_BIN)
@@ -41,6 +44,34 @@ enum {
 
 static GParamSpec *props[LAST_PROP];
 
+static gboolean
+is_window_compatible (GObject *item)
+{
+  return ADW_IS_WINDOW (item) || ADW_IS_APPLICATION_WINDOW (item);
+}
+
+static GtkWidget *
+create_window_row_cb (GtkWindow        *window,
+                      AdwInspectorPage *self)
+{
+  GtkWidget *row, *btn;
+
+  row = adw_action_row_new ();
+  g_object_bind_property (window, "title", row, "title", G_BINDING_SYNC_CREATE);
+  adw_action_row_set_subtitle (ADW_ACTION_ROW (row), G_OBJECT_TYPE_NAME (window));
+
+  btn = gtk_toggle_button_new ();
+  gtk_button_set_icon_name (GTK_BUTTON (btn), "adw-adaptive-preview-symbolic");
+  gtk_widget_set_tooltip_text (btn, _("Adaptive Preview"));
+  gtk_widget_set_valign (btn, GTK_ALIGN_CENTER);
+  gtk_widget_add_css_class (btn, "flat");
+  g_object_bind_property (window, "adaptive-preview", btn, "active",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  adw_action_row_add_suffix (ADW_ACTION_ROW (row), btn);
+
+  return row;
+}
+
 static void
 color_scheme_changed_cb (AdwInspectorPage *self)
 {
@@ -309,6 +340,20 @@ adw_inspector_page_dispose (GObject *object)
   G_OBJECT_CLASS (adw_inspector_page_parent_class)->dispose (object);
 }
 
+static void
+adw_inspector_page_realize (GtkWidget *widget)
+{
+  AdwInspectorPage *self = ADW_INSPECTOR_PAGE (widget);
+
+  GTK_WIDGET_CLASS (adw_inspector_page_parent_class)->realize (widget);
+
+  if (!self->realized) {
+    gtk_icon_theme_add_resource_path (gtk_icon_theme_get_for_display (gtk_widget_get_display (GTK_WIDGET (self))),
+                                    "/org/gnome/Adwaita/icons");
+    self->realized = TRUE;
+  }
+}
+
 static void
 adw_inspector_page_class_init (AdwInspectorPageClass *klass)
 {
@@ -319,6 +364,8 @@ adw_inspector_page_class_init (AdwInspectorPageClass *klass)
   object_class->set_property = adw_inspector_page_set_property;
   object_class->dispose = adw_inspector_page_dispose;
 
+  widget_class->realize = adw_inspector_page_realize;
+
   props[PROP_TITLE] =
     g_param_spec_string ("title", NULL, NULL,
                          "Libadwaita",
@@ -339,6 +386,7 @@ adw_inspector_page_class_init (AdwInspectorPageClass *klass)
   gtk_widget_class_bind_template_child (widget_class, AdwInspectorPage, high_contrast_row);
   gtk_widget_class_bind_template_child (widget_class, AdwInspectorPage, support_accent_colors_row);
   gtk_widget_class_bind_template_child (widget_class, AdwInspectorPage, accent_color_row);
+  gtk_widget_class_bind_template_child (widget_class, AdwInspectorPage, windows_list);
 
   gtk_widget_class_bind_template_callback (widget_class, get_system_color_scheme_name);
   gtk_widget_class_bind_template_callback (widget_class, get_accent_color_name);
@@ -358,6 +406,8 @@ adw_inspector_page_init (AdwInspectorPage *self)
   AdwSystemColorScheme color_scheme;
   AdwAccentColor accent_color;
   gboolean supports, hc;
+  GtkFilter *filter;
+  GtkFilterListModel *windows;
 
   self->settings = adw_settings_get_default ();
 
@@ -379,4 +429,15 @@ adw_inspector_page_init (AdwInspectorPage *self)
 
   supports = adw_settings_get_system_supports_accent_colors (self->settings);
   adw_switch_row_set_active (self->support_accent_colors_row, supports);
+
+  filter = GTK_FILTER (gtk_custom_filter_new ((GtkCustomFilterFunc) is_window_compatible, NULL, NULL));
+  windows = gtk_filter_list_model_new (g_object_ref (gtk_window_get_toplevels ()), filter);
+
+  gtk_list_box_bind_model (self->windows_list,
+                           G_LIST_MODEL (windows),
+                           (GtkListBoxCreateWidgetFunc) create_window_row_cb,
+                           self,
+                           NULL);
+
+  g_object_unref (windows);
 }
