@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
+ * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
  */
 
 #pragma once
@@ -13,11 +13,12 @@
 #endif
 
 #include "adw-toast.h"
+#include "adw-toast-overlay.h"
 
 G_BEGIN_DECLS
 
-gboolean adw_toast_get_added (AdwToast *self);
-void     adw_toast_set_added (AdwToast *self,
-                              gboolean  added);
+AdwToastOverlay *adw_toast_get_overlay (AdwToast        *self);
+void             adw_toast_set_overlay (AdwToast        *self,
+                                        AdwToastOverlay *overlay);
 
 G_END_DECLS
