@@ -67,4 +67,11 @@ GtkWidget *adw_widget_get_ancestor (GtkWidget *widget,
 
 gboolean adw_decoration_layout_prefers_start (const char *layout);
 
+char *adw_strip_mnemonic (const char *src);
+
+void adw_ensure_child_allocation_size (GtkWidget     *child,
+                                       GtkAllocation *allocation);
+
+gboolean adw_get_inspector_keybinding_enabled (void);
+
 G_END_DECLS
